@@ -11,15 +11,15 @@ class ProcessorParameters(BaseModel):
 
 
 class ProcessorBase(metaclass=ABCSingleton):
-    """Base class for example plugin used in the tutorial.
-    """
+    """Base class for example plugin used in the tutorial."""
 
     def __init__(self):
         pass
 
     @abc.abstractmethod
-    def process(self, documents: List[Document], options: ProcessorParameters) \
-            -> List[Document]:
+    def process(
+        self, documents: List[Document], options: ProcessorParameters
+    ) -> List[Document]:
         """Process the input documents and return the modified documents.
 
         :param documents: A list of annotated documents.
