@@ -12,7 +12,10 @@ def test_formatter():
     with pytest.raises(TypeError) as err:
         parser = FormatterBase()
         assert parser is None
-    assert "Can't instantiate abstract class FormatterBase with abstract methods format" in str(err.value)
+    assert (
+        "Can't instantiate abstract class FormatterBase with abstract methods format"
+        in str(err.value)
+    )
 
 
 def test_default_options():
@@ -26,17 +29,11 @@ class DummyParameters(FormatterParameters):
 
 
 class DummyFormatter(FormatterBase):
-    """Dummy formatter.
-    """
+    """Dummy formatter."""
 
-    def format(self, document: Document, parameters: FormatterParameters) \
-            -> Response:
+    def format(self, document: Document, parameters: FormatterParameters) -> Response:
         parameters: DummyParameters = parameters
-        output = {
-            "text": document.text,
-            "foo": parameters.foo,
-            "bar": parameters.bar
-        }
+        output = {"text": document.text, "foo": parameters.foo, "bar": parameters.bar}
         return JSONResponse(content=output)
 
     @classmethod
@@ -47,6 +44,8 @@ class DummyFormatter(FormatterBase):
 def test_dummy():
     formatter = DummyFormatter()
     options = DummyParameters()
-    resp: Response = formatter.format(Document(text="This is a test document", metadata=options.dict()), options)
+    resp: Response = formatter.format(
+        Document(text="This is a test document", metadata=options.dict()), options
+    )
     assert resp.status_code == 200
     assert resp.media_type == "application/json"
