@@ -11,7 +11,10 @@ def test_segmenter():
     with pytest.raises(TypeError) as err:
         parser = SegmenterBase()
         assert parser is None
-    assert "Can't instantiate abstract class SegmenterBase with abstract methods segment" in str(err.value)
+    assert (
+        "Can't instantiate abstract class SegmenterBase with abstract methods segment"
+        in str(err.value)
+    )
 
 
 def test_default_options():
@@ -25,13 +28,16 @@ class DummyParameters(SegmenterParameters):
 
 
 class Dummysegmenter(SegmenterBase):
-    """Dummy segmenter.
-    """
+    """Dummy segmenter."""
 
-    def segment(self, documents: List[Document], parameters: SegmenterParameters) -> List[Document]:
+    def segment(
+        self, documents: List[Document], parameters: SegmenterParameters
+    ) -> List[Document]:
         parameters: DummyParameters = parameters
-        documents[0].sentences = [{'start': 0, 'end': 1}]
-        documents[0].boundaries = {parameters.foo: [{'name': parameters.bar, 'start': 0, 'end': 1}]}
+        documents[0].sentences = [{"start": 0, "end": 1}]
+        documents[0].boundaries = {
+            parameters.foo: [{"name": parameters.bar, "start": 0, "end": 1}]
+        }
         return documents
 
     @classmethod
@@ -42,7 +48,8 @@ class Dummysegmenter(SegmenterBase):
 def test_dummy():
     segmenter = Dummysegmenter()
     options = DummyParameters()
-    docs: List[Document] =\
-        segmenter.segment([Document(text="This is a test document.", metadata=options.dict())], options)
+    docs: List[Document] = segmenter.segment(
+        [Document(text="This is a test document.", metadata=options.dict())], options
+    )
     assert len(docs[0].sentences) == 1
     assert len(docs[0].boundaries) == 1
